@@ -16,9 +16,10 @@
 from calculate.core.server.local_call import Display, Methods, has_force_arg
 from calculate.lib.utils.tools import unpack_single_opts
 
-from sudsds import WebFault
-from sudsds.transport import TransportError
-
+# from sudsds import WebFault
+from suds import WebFault
+# from sudsds.transport import TransportError
+from suds.transport import TransportError
 from client_class import Client_suds
 import traceback as tb
 import time
@@ -383,10 +384,10 @@ def main(wait_thread):
                 list(unpack_single_opts(sys.argv[1:])))
 
     logging.basicConfig(level=logging.FATAL)
-    logging.getLogger('sudsds.client').setLevel(logging.FATAL)
-    logging.getLogger('sudsds.transport').setLevel(logging.FATAL)
-    logging.getLogger('sudsds.transport.http').setLevel(logging.FATAL)
-    logging.getLogger('sudsds.umx.typed').setLevel(logging.ERROR)
+    logging.getLogger('suds.client').setLevel(logging.FATAL)
+    logging.getLogger('suds.transport').setLevel(logging.FATAL)
+    logging.getLogger('suds.transport.http').setLevel(logging.FATAL)
+    logging.getLogger('suds.umx.typed').setLevel(logging.ERROR)
 
     clVarsCore = DataVarsCore()
     clVarsCore.importCore()
