@@ -27,8 +27,8 @@ from calculate.core.server.cert_cmd import getHwAddr, getIpLocal
 from calculate.core.server.local_call import print_brief_group
 from calculate.lib.cl_lang import setLocalTranslate
 from calculate.lib.utils.files import readFile
-from sudsds import MethodNotFound
-
+# from sudsds import MethodNotFound
+from suds import MethodNotFound
 _ = lambda x: x
 setLocalTranslate('cl_console3', sys.modules[__name__])
 
